DiskLayout

Enum DiskLayout 

pub enum DiskLayout {
Show 84 variants Abb320kb, Abb328kb, Abb640kb, AcornAdfs160k, AcornAdfm320k, AcornAdfl640k, Aed6200p, Akais950Hd1600kb, Akais950Dd800kb, Akais3000Hd, AlesisDatadiskDd800kb, AmstradcpcDd, AutomatixRailDd400kb, AtaristDd720kb, BungMgd2, Casiofz1Hd1m25, RoboxRc9400, Comx35Ss70kb, Comx35Ds140kb, Comx35Ss140kb, DecRx55, DidaktikSpectrumDd720kb, DosDd720kb, DosHd1m44, DosEd2m88, DosExdd2m5, DosExhd4m5, DosExhd6m78, DynacordAddOne, DynacordHd, EnsoniqDd800kb, EnsoniqHd1600kb, EnsoniqMirage440kb, ExcellonCnc6, EmaxDd800kb, EmaxIiDd800kb, FlexSsdd80t358kb, FlexDsdd80t716kb, FlexDsdd80t716kbPadded, FlexDsdd40t356kb, FlexDsdd40t356kbPadded, GeneralmusicGemS31600kb, GeneralmusicGemWxExpander, GravographIsis640kb, Korgdss1Dd800kb, Korgt3Hd1m6, Lif350264kb, Lif350616kb, Lif35o1232kb, Lif525264kb, Linnforat9k720kb, Memotech80t, Memotech40t, Microtan65Tandos, Balzers250kb, OpusDiscovery, Os9640kb, Os91280kb, OricJasmin357kb, PumaRobotDd640kb, QdTriumphAdler, RolandDdW30, RolandDdS330W50S50S550, RolandDdMc50Mc300Mc500, SordM68Hd998kb, TatungEinsteinDd200kb, TatungEinsteinDd400kb, TimexFdd300080t2s, TimexFdd300040t1s, Trs80Jv1, UkncMfm800kb, UnitelVideotexFloppyDisk, X680002hd1232kb, AnalogdevicesLts2020, VideobitSistemaS80, OtronaAttache, SeattleComputerGazelleSssd, SeattleComputerGazelleDssd, SeattleComputerGazelleSsdd, SeattleComputerGazelleDsdd, KayproDsdd, KayproSsdd, ResearchMachinesSssd, ResearchMachinesDsdd,
}
Predefined disk layout.

Represents the different predefined disk layouts supported by the HxC library. This enum is automatically generated from LayoutsIndex.h.

Variants



Abb320kb

ABB_320KB



Abb328kb

ABB_328KB



Abb640kb

ABB_640KB



AcornAdfs160k

ACORN_ADFS_160K



AcornAdfm320k

ACORN_ADFM_320K



AcornAdfl640k

ACORN_ADFL_640K



Aed6200p

AED_6200P



Akais950Hd1600kb

AKAIS950_HD_1600KB



Akais950Dd800kb

AKAIS950_DD_800KB



Akais3000Hd

AKAIS3000_HD



AlesisDatadiskDd800kb

ALESIS_DATADISK_DD_800KB



AmstradcpcDd

AMSTRADCPC_DD



AutomatixRailDd400kb

AUTOMATIX_RAIL_DD_400KB



AtaristDd720kb

ATARIST_DD_720KB



BungMgd2

BUNG_MGD2



Casiofz1Hd1m25

CASIOFZ1_HD_1M25



RoboxRc9400

ROBOX_RC9400



Comx35Ss70kb

COMX35_SS_70KB



Comx35Ds140kb

COMX35_DS_140KB



Comx35Ss140kb

COMX35_SS_140KB



DecRx55

DEC_RX55



DidaktikSpectrumDd720kb

Didaktik_Spectrum_DD_720KB



DosDd720kb

DOS_DD_720KB



DosHd1m44

DOS_HD_1M44



DosEd2m88

DOS_ED_2M88



DosExdd2m5

DOS_EXDD_2M5



DosExhd4m5

DOS_EXHD_4M5



DosExhd6m78

DOS_EXHD_6M78



DynacordAddOne

DYNACORD_ADD_ONE



DynacordHd

DYNACORD_HD



EnsoniqDd800kb

ENSONIQ_DD_800KB



EnsoniqHd1600kb

ENSONIQ_HD_1600KB



EnsoniqMirage440kb

ENSONIQ_MIRAGE_440KB



ExcellonCnc6

EXCELLON_CNC6



EmaxDd800kb

EMAX_DD_800KB



EmaxIiDd800kb

EMAX_II_DD_800KB



FlexSsdd80t358kb

FLEX_SSDD_80T_358KB



FlexDsdd80t716kb

FLEX_DSDD_80T_716KB



FlexDsdd80t716kbPadded

FLEX_DSDD_80T_716KB_PADDED



FlexDsdd40t356kb

FLEX_DSDD_40T_356KB



FlexDsdd40t356kbPadded

FLEX_DSDD_40T_356KB_PADDED



GeneralmusicGemS31600kb

GENERALMUSIC_GEM_S3_1600KB



GeneralmusicGemWxExpander

GENERALMUSIC_GEM_WX_EXPANDER



GravographIsis640kb

GRAVOGRAPH_ISIS_640KB



Korgdss1Dd800kb

KORGDSS1_DD_800KB



Korgt3Hd1m6

KORGT3_HD_1M6



Lif350264kb

LIF_3_50_264KB



Lif350616kb

LIF_3_50_616KB



Lif35o1232kb

LIF_3_5O_1232KB



Lif525264kb

LIF_5_25_264KB



Linnforat9k720kb

LINNFORAT9K_720KB



Memotech80t

MEMOTECH_80T



Memotech40t

MEMOTECH_40T



Microtan65Tandos

MICROTAN_65_TANDOS



Balzers250kb

BALZERS_250KB



OpusDiscovery

OPUS_DISCOVERY



Os9640kb

OS9_640KB



Os91280kb

OS9_1280KB



OricJasmin357kb

ORIC_JASMIN_357KB



PumaRobotDd640kb

PUMA_ROBOT_DD_640KB



QdTriumphAdler

QD_TRIUMPH_ADLER



RolandDdW30

ROLAND_DD_W30



RolandDdS330W50S50S550

ROLAND_DD_S330_W50_S50_S550



RolandDdMc50Mc300Mc500

ROLAND_DD_MC50_MC300_MC500



SordM68Hd998kb

SORD_M68_HD_998KB



TatungEinsteinDd200kb

TATUNG_EINSTEIN_DD_200KB



TatungEinsteinDd400kb

TATUNG_EINSTEIN_DD_400KB



TimexFdd300080t2s

TIMEX_FDD3000_80T2S



TimexFdd300040t1s

TIMEX_FDD3000_40T1S



Trs80Jv1

TRS80_JV1



UkncMfm800kb

UKNC_MFM_800KB



UnitelVideotexFloppyDisk

UNITEL_VIDEOTEX_FLOPPY_DISK



X680002hd1232kb

X68000_2HD_1232KB



AnalogdevicesLts2020

ANALOGDEVICES_LTS2020



VideobitSistemaS80

VIDEOBIT_SISTEMA_S80



OtronaAttache

OTRONA_ATTACHE



SeattleComputerGazelleSssd

SEATTLE_COMPUTER_GAZELLE_SSSD



SeattleComputerGazelleDssd

SEATTLE_COMPUTER_GAZELLE_DSSD



SeattleComputerGazelleSsdd

SEATTLE_COMPUTER_GAZELLE_SSDD



SeattleComputerGazelleDsdd

SEATTLE_COMPUTER_GAZELLE_DSDD



KayproDsdd

KAYPRO_DSDD



KayproSsdd

KAYPRO_SSDD



ResearchMachinesSssd

RESEARCH_MACHINES_SSSD



ResearchMachinesDsdd

RESEARCH_MACHINES_DSDD

Implementations

Source

impl DiskLayout

pub fn layout_name(&self) -> &'static str

Get the disk layout name string

pub fn from_str(s: &str) -> Option<DiskLayout>

Parse from a layout name string

pub fn from_usize(value: usize) -> Option<DiskLayout>

Convert from a usize value

pub fn id(&self, hxcfe_xmlldr: *mut _HXCFE_XMLLDR) -> i32

Get the disk layout ID from the C library.

The ID is retrieved at runtime by querying the C library with the layout name. Panics if the layout is not found (which indicates a bug in the bindings).

Arguments
  • hxcfe_xmlldr - The HxC XML loader context
Returns

The layout ID

pub fn all() -> &'static [DiskLayout]

Get all available disk layouts